Imports Microsoft.VisualBasic

Public Class JPGThumbnail

    Private Enum Method
        File
        Stream
    End Enum

    Private Sub New()
    End Sub

    Public Shared Sub CreateThumbnail(ByVal InputFilePath As String, ByVal intMaxLen As Integer, ByVal OutputStream As IO.Stream)
        CreateThumbnail(InputFilePath, intMaxLen, Method.Stream, , OutputStream)
    End Sub

    Public Shared Sub CreateThumbnail(ByVal InputFilePath As String, ByVal intMaxLen As Integer, ByVal OutputFilePath As String)
        CreateThumbnail(InputFilePath, intMaxLen, Method.File, OutputFilePath)
    End Sub

    Private Shared Sub CreateThumbnail(ByVal InputFilePath As String, ByVal intMaxLen As Integer, ByVal ThumbnailMethod As Method, Optional ByVal OutputFilePath As String = "", Optional ByVal OutputStream As IO.Stream = Nothing)
        Dim fileInfo As New IO.FileInfo(InputFilePath)

        If fileInfo.Exists() Then

            Dim bmp As System.Drawing.Bitmap
            Dim bmpThumb As System.Drawing.Bitmap

            Try
                bmp = New System.Drawing.Bitmap(InputFilePath)
                Dim intWidth As Integer = bmp.Width
                Dim intHeight As Integer = bmp.Height
                Dim intThumbWidth As Integer
                Dim intThumbHeight As Integer

                If intWidth > intHeight Then
                    intThumbWidth = intMaxLen
                    intThumbHeight = (intHeight / intWidth) * intMaxLen
                Else
                    intThumbHeight = intMaxLen
                    intThumbWidth = (intWidth / intHeight) * intMaxLen
                End If

                Dim thumbSize As New Drawing.Size(intThumbWidth, intThumbHeight)
                bmpThumb = New System.Drawing.Bitmap(bmp, thumbSize)

                If intMaxLen >= intHeight Or intMaxLen >= intWidth Then
                    ' Save the original 
                    If ThumbnailMethod = Method.File Then
                        bmp.Save(OutputFilePath, System.Drawing.Imaging.ImageFormat.Jpeg)
                        bmp.Save(OutputFilePath, System.Drawing.Imaging.ImageFormat.Gif)
                        bmp.Save(OutputFilePath, System.Drawing.Imaging.ImageFormat.Png)
                    Else
                        bmp.Save(OutputStream, System.Drawing.Imaging.ImageFormat.Jpeg)
                        bmp.Save(OutputStream, System.Drawing.Imaging.ImageFormat.Gif)
                        bmp.Save(OutputStream, System.Drawing.Imaging.ImageFormat.Png)
                    End If
                Else
                    ' Save the thumbnail version 
                    If ThumbnailMethod = Method.File Then
                        bmpThumb.Save(OutputFilePath, System.Drawing.Imaging.ImageFormat.Jpeg)
                        bmpThumb.Save(OutputFilePath, System.Drawing.Imaging.ImageFormat.Gif)
                        bmpThumb.Save(OutputFilePath, System.Drawing.Imaging.ImageFormat.Png)
                    Else
                        bmpThumb.Save(OutputStream, System.Drawing.Imaging.ImageFormat.Jpeg)
                        bmpThumb.Save(OutputStream, System.Drawing.Imaging.ImageFormat.Gif)
                        bmpThumb.Save(OutputStream, System.Drawing.Imaging.ImageFormat.Png)
                    End If

                End If

            Catch ex As Exception
                Throw
                'WriteErrorMsg(OutputFilePath) 
            Finally
                'clean-up 
                bmp.Dispose()
                bmpThumb.Dispose()
            End Try


        Else
            Throw New ApplicationException("Input file [" & InputFilePath & "] does not exist.")
        End If

    End Sub

    '* This can be used to return an image even in an error condition, if thats what you want. 
    'Private Shared Sub WriteErrorMsg(ByVal OutputFilePath As String) 

    '    Dim bmp As New System.Drawing.Bitmap(100, 100, System.Drawing.Imaging.PixelFormat.Format16bppRgb565) 
    '     Get the underlying Graphics object. 
    '    Dim gr As System.Drawing.Graphics = System.Drawing.Graphics.FromImage(bmp) 
    '     Clear its background. 
    '    gr.Clear(System.Drawing.Color.WhiteSmoke) 

    '     create a font 
    '    Dim fnt As New System.Drawing.Font(Arial, 8, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point) 

    '    gr.DrawString(Not, fnt, System.Drawing.Brushes.Blue, 36, 30) 
    '    gr.DrawString(Available, fnt, System.Drawing.Brushes.Blue, 23, 50) 

    '    Dim penRect As New System.Drawing.Pen(Color.LightBlue, 2) 
    '    gr.DrawRectangle(penRect, 1, 1, 98, 98) 

    '     Release resources. 
    '    fnt.Dispose() 
    '    gr.Dispose() 

    '    bmp.Save(OutputFilePath, System.Drawing.Imaging.ImageFormat.Jpeg) 
    '    bmp.Dispose() 
    'End Sub 


End Class
